////////////////////////////////////////////////////////////////////////
// FILE:  block.h
////////////////////////////////////////////////////////////////////////

class BLOCK {
public:

	  // dimensions
	float hw;  // half width   (right, X)
	float hh;  // half height  (up, Z)
	float hd;  // half depth   (in, Y)

	TMAT IB;  // inertia tensor in local coords
	double mass;      // mass (kg)

	  // block state
	VEC4 P;   // block position
	VEC4 V;   // block velocity
	VEC4 Q;   // block orientation quaternion
	VEC4 L;   // block angular momentum

	TMAT R;     // rotation matrix 
	TMAT TM;    // full transformation matrix:  rotation + translation
	VEC4 omega; // angular velocity
	TMAT I;     // inertia tensor in inertial coord frame
	TMAT Iinv;  // inverse of inertia tensor

	VEC4 vertex[8];        // vertices of block in local coords
	VEC4 vertexW[8];       // vertices of block in world coords
	float faceV[6][4];     // six block faces
	float faceColor[6][3]; // face colors

	void initDim(float hw, float hh, float hd, float m);
	void initState();          // set initial state of block
	void draw(bool shadow);    // draws block
	void sim();                // simulate one time step
	void print();              // prints all info about the block
	void transformVertices();  // transform vertices to world coords
	void collisionCheck();     // check and process collisions, if any
	void collisionImpulse(int n);   // process collision
};

extern BLOCK Block;
