#include <GL/glut.h>
#include <math.h>

#include "draw.h"
#include "lib_math.h"
#include "main.h"
#include "block.h"


///////////////////////////////////////////////////
// FN:  drawGround()
///////////////////////////////////////////////////

void drawGround()
{
	const float D=100;
	glPushMatrix();

	glTranslatef(0,0,-0.01);
	glColor3f(0.8,0.8,0.4);
	glBegin(GL_POLYGON);
	glVertex3f(-D,-D,0);
	glVertex3f(D,-D,0);
	glVertex3f(D,D,0);
	glVertex3f(-D,D,0);
	glEnd();

	glPopMatrix();
}

///////////////////////////////////////////////////
// FN:  drawShadow()
///////////////////////////////////////////////////

void drawShadow()
{
	  // vector pointing to light source
	const float light[3]= {7.0,-8.0,10.0};
	GLfloat shadowMatrix[16] = {
		1,0,0,0,
		0,1,0,0,
		-light[0]/light[2],-light[1]/light[2],0,0,
		0,0,0,1
	};
	bool shadow = true;

	glPushMatrix();
	glMultMatrixf(shadowMatrix);
	glColor3f(0.1, 0.1, 0.1);
	Block.draw(shadow);
	glPopMatrix();
}

///////////////////////////////////////////////////
// FN:  drawGrid()
///////////////////////////////////////////////////

void drawGrid()
{
	const float min = -10;
	const float max = 10;
	const int nsteps = 20;
	float dstep = (max-min)/nsteps;

	glColor3f(0,0,0);
	  // draw horizontal lines
	glBegin(GL_LINES);
	for (float y=min; y<=max; y+=dstep) {
		glVertex3f(min,y,0);
		glVertex3f(max,y,0);
	}
	glEnd();

	  // draw vertical lines
	glBegin(GL_LINES);
	for (float x=min; x<=max; x+=dstep) {
		glVertex3f(x,min,0);
		glVertex3f(x,max,0);
	}
	glEnd();

}

///////////////////////////////////////////////////
// FN:  displayCB()
//      This is the display call back for glut.
//      It is called whenever a the display window needs to be redrawn
////////////////////////////////////////////////////

void displayCB()
{
	bool shadow = false;

	glClearColor(1,1,1,1);
    glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
	glPushMatrix();

	drawGround();
	drawGrid();
	drawShadow();
	Block.draw(false);

	glPopMatrix();

    glutSwapBuffers();
}

